Pyramid GeoREST interface
=========================

pyramid_georest is a open source plugin for the pyramid web framework. It provides access to geographical
and (also non geographical) database sources via a restful API.

Please refer to the detailed [documentation](https://vvmruder.github.io/pyramid_georest 'documentation')
to learn what it does exactly and how to install/use it.
